/*
Copyright 2021.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1alpha1

import corev1 "k8s.io/api/core/v1"

type ApplicationParameters struct {
	// Domain is the domain of the application
	// +optional
	Domain string `json:"domain,omitempty"`

	// +optional
	EnableSSO bool `json:"enableSSO,omitempty"`

	// +optional
	OIDC map[string]OIDCParameters `json:"oidc,omitempty"`

	// +optional
	SAML map[string]OIDCParameters `json:"saml,omitempty"`

	// +optional
	Postgres map[string]PostgresParameters `json:"postgres,omitempty"`
}

type OIDCParameters struct {
	// +optional
	ClientId string `json:"clientId,omitempty"`

	// +optional
	ClientSecret string `json:"clientSecret,omitempty"`

	// +optional
	DiscoveryEndpoint string `json:"discoveryEndpoint,omitempty"`

	// +optional
	AuthorizationEndpoint string `json:"authorizationEndpoint,omitempty"`

	// +optional
	TokenEndpoint string `json:"tokenEndpoint,omitempty"`

	// +optional
	IntrospectionEndpoint string `json:"introspectionEndpoint,omitempty"`

	// +optional
	UserinfoEndpoint string `json:"userinfoEndpoint,omitempty"`

	// +optional
	EndSessionEndpoint string `json:"endSessionEndpoint,omitempty"`
}

type SAMLParameters struct {
	// +optional
	IDPEntityId string `json:"idpEntityId,omitempty"`

	// +optional
	IDPx509cert string `json:"idpx509cert,omitempty"`

	// +optional
	IDPSingleSignOnService string `json:"ipdSingleSignOnService,omitempty"`

	// +optional
	IDPSingleLogoutService string `json:"idpSingleLogoutService,omitempty"`

	// +optional
	ServiceCertificateRef *corev1.SecretReference `json:"serviceCertificateRef,omitempty"`
}

type PostgresParameters struct {
	// +optional
	Host string `json:"host,omitempty"`

	// +optional
	DBName string `json:"dbname,omitempty"`

	// +optional
	User string `json:"user,omitempty"`

	// +optional
	Password string `json:"password,omitempty"`
}
