/*
Copyright 2021.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.
*/

package v1alpha1

import (
	"github.com/fluxcd/pkg/runtime/dependency"
	apiextensionsv1 "k8s.io/apiextensions-apiserver/pkg/apis/apiextensions/v1"
)

type StackTemplate struct {
	// Domain is the root domain of the applications
	// +optional
	Domain string `json:"domain,omitempty"`

	// +optional
	SSO SSOTemplate `json:"sso,omitempty"`

	// +optional
	Postgres PostgresTemplate `json:"postgres,omitempty"`

	// Applications is a map of InstanceApplications
	// +optional
	Applications map[string]ApplicationTemplate `json:"applications,omitempty"`
}

type SSOTemplate struct {
	// +optional
	Disabled bool `json:"disabled,omitempty"`

	// +optional
	Unmanaged bool `json:"unmanage,omitempty"`

	// +optional
	KeycloakAccess *KeycloakAccess `json:"keycloakAccess,omitempty"`

	// +optional
	KeycloakRealm *apiextensionsv1.JSON `json:"keycloakRealm,omitempty"`
}

type PostgresTemplate struct {
	// +optional
	CPU string `json:"cpu,omitempty"`

	// +optional
	Memory string `json:"memory,omitempty"`

	// +optional
	Size string `json:"size,omitempty"`
}

type ApplicationTemplate struct {
	// Disabled tells the controller to skip this application
	// +optional
	Disabled bool `json:"disabled,omitempty"`

	// Application is the reference to the application
	// +optional
	Application dependency.CrossNamespaceDependencyReference `json:"application,omitempty"`

	// Parameters overwrites parameters generated by the controller.
	// +optional
	Parameters ApplicationParameters `json:"parameters,omitempty"`

	// +optional
	Values *apiextensionsv1.JSON `json:"values,omitempty"`
}
