package controllers

import (
	"fmt"

	"k8s.io/apimachinery/pkg/apis/meta/v1/unstructured"
)

func (w *StackWrapper) SetPostgresMeta(o *unstructured.Unstructured) {
	o.SetAPIVersion("acid.zalan.do/v1")
	o.SetKind("postgresql")
	o.SetName(fmt.Sprintf("pg-%s", w.Stack.ObjectMeta.Name))
	o.SetNamespace(w.Stack.ObjectMeta.Namespace)
}

func (w *StackWrapper) SetPostgresSpec(o *unstructured.Unstructured) {
	users := make(map[string][]string)
	databases := make(map[string]string)

	for appName, app := range w.Applications {
		appTpl := w.ApplicationTemplate(appName)
		if appTpl.Disabled {
			continue
		}

		for k := range app.Spec.Traits.Postgres {
			var n string
			if k == "main" {
				n = appName
			} else {
				n = fmt.Sprintf("%s-%s", appName, k)
			}

			users[n] = []string{
				"superuser",
				"createdb",
			}

			databases[n] = n
		}
	}

	resources := map[string]interface{}{
		"cpu":    w.Template.Postgres.CPU,
		"memory": w.Template.Postgres.Memory,
	}

	o.Object["spec"] = map[string]interface{}{
		"teamId":            "pg",
		"numberOfInstances": 3,
		"postgresql": map[string]interface{}{
			"version": "11",
		},
		"volume": map[string]interface{}{
			"size": w.Template.Postgres.Size,
		},
		"databases": databases,
		"users":     users,
		"resources": map[string]interface{}{
			"requests": resources,
			"limits":   resources,
		},
	}

}

func (w *StackWrapper) IsPostgres() bool {
	for appName, app := range w.Applications {
		appTpl := w.ApplicationTemplate(appName)
		if appTpl.Disabled {
			continue
		}

		if len(app.Spec.Traits.Postgres) > 0 {
			return true
		}
	}
	return false
}
